@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,17 +17,21 @@
 
 
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 from otopi import util
 from otopi import plugin
 
 
+from ovirt_engine_setup.engine import constants as oenginecons
 from ovirt_engine_setup import constants as osetupcons
 from ovirt_engine_setup.dwh import constants as odwhcons
 
 
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-dwh')
+
+
 @util.export
 class Plugin(plugin.PluginBase):
 
@@ -39,7 +43,7 @@ class Plugin(plugin.PluginBase):
     )
     def _init(self):
         self.environment.setdefault(odwhcons.CoreEnv.ENABLE, None)
-        self.environment.setdefault(odwhcons.EngineCoreEnv.ENABLE, None)
+        self.environment.setdefault(oenginecons.CoreEnv.ENABLE, None)
 
     @plugin.event(
         stage=plugin.Stages.STAGE_SETUP,
